@@ -45,7 +45,6 @@ public class Medialibrary {
     public static final int FLAG_MEDIA_ADDED_AUDIO_EMPTY    = 1 << 4;
     public static final int FLAG_MEDIA_ADDED_VIDEO          = 1 << 5;
 
-    private static final String extDirPath = Environment.getExternalStorageDirectory().getAbsolutePath();
     public static final String ACTION_IDLE = "action_idle";
     public static final String STATE_IDLE = "state_idle";
 
@@ -66,8 +65,6 @@ public class Medialibrary {
     private AlbumsModifiedCb mAlbumsModifiedCb = null;
     private final List<DevicesDiscoveryCb> devicesDiscoveryCbList = new ArrayList<>();
     private final List<EntryPointsEventsCb> entryPointsEventsCbList = new ArrayList<>();
-
-    private static Medialibrary sInstance;
     private static Context sContext;
 
     static {
@@ -76,6 +73,10 @@ public class Medialibrary {
         System.loadLibrary("mla");
     }
 
+    private static class MedialibraryHolder {
+        public static final Medialibrary instance = new Medialibrary();
+    }
+
     public static Context getContext() {
         return sContext;
     }
@@ -86,7 +87,8 @@ public class Medialibrary {
         sContext = context;
         File extFilesDir = context.getExternalFilesDir(null);
         File dbDirectory = context.getDir("db", Context.MODE_PRIVATE);
-        if (extFilesDir == null || !extFilesDir.exists())
+        if (extFilesDir == null || !extFilesDir.exists()
+                || dbDirectory == null || !dbDirectory.canWrite())
             return false;
         mIsInitiated = nativeInit(dbDirectory+ VLC_MEDIA_DB_NAME, extFilesDir+ THUMBS_FOLDER_NAME);
         return mIsInitiated;
@@ -142,10 +144,8 @@ public class Medialibrary {
         super.finalize();
     }
 
-    public static synchronized Medialibrary getInstance() {
-        if (sInstance == null)
-            sInstance = new Medialibrary();
-        return sInstance;
+    public static Medialibrary getInstance() {
+        return MedialibraryHolder.instance;
     }
 
     @WorkerThread
