@@ -36,10 +36,10 @@ import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.SearchActivity;
 import org.videolan.vlc.gui.tv.MainTvActivity;
 import org.videolan.vlc.gui.tv.audioplayer.AudioPlayerActivity;
-import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Permissions;
+import org.videolan.vlc.util.Util;
 
 public class StartActivity extends Activity {
 
@@ -52,28 +52,25 @@ public class StartActivity extends Activity {
     @Override
     protected void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
-        Intent intent = getIntent();
-        boolean tv =  showTvUi();
-        String action = intent != null ? intent.getAction(): null;
+        final Intent intent = getIntent();
+        final boolean tv =  showTvUi();
+        final String action = intent != null ? intent.getAction(): null;
 
         if (Intent.ACTION_VIEW.equals(action) && intent.getData() != null) {
             intent.setDataAndType(intent.getData(), intent.getType());
-            if (intent.getType() != null && intent.getType().startsWith("video"))
-                startActivity(intent.setClass(this, VideoPlayerActivity.class));
-            else
-                MediaUtils.openMediaNoUi(intent.getData());
+            MediaUtils.openMediaNoUi(intent.getData());
             finish();
             return;
         }
 
         // Start application
         /* Get the current version from package */
-        SharedPreferences settings = PreferenceManager.getDefaultSharedPreferences(this);
-        int currentVersionNumber = BuildConfig.VERSION_CODE;
-        int savedVersionNumber = settings.getInt(PREF_FIRST_RUN, -1);
+        final SharedPreferences settings = PreferenceManager.getDefaultSharedPreferences(this);
+        final int currentVersionNumber = BuildConfig.VERSION_CODE;
+        final int savedVersionNumber = settings.getInt(PREF_FIRST_RUN, -1);
         /* Check if it's the first run */
-        boolean firstRun = savedVersionNumber == -1;
-        boolean upgrade = firstRun || savedVersionNumber != currentVersionNumber;
+        final boolean firstRun = savedVersionNumber == -1;
+        final boolean upgrade = firstRun || savedVersionNumber != currentVersionNumber;
         if (upgrade)
             settings.edit().putInt(PREF_FIRST_RUN, currentVersionNumber).apply();
         startMedialibrary(firstRun, upgrade);
@@ -83,9 +80,9 @@ public class StartActivity extends Activity {
             finish();
             return;
         } else if (MediaStore.INTENT_ACTION_MEDIA_PLAY_FROM_SEARCH.equals(action)) {
-            Intent serviceInent = new Intent(PlaybackService.ACTION_PLAY_FROM_SEARCH, null, this, PlaybackService.class)
+            final Intent serviceInent = new Intent(PlaybackService.ACTION_PLAY_FROM_SEARCH, null, this, PlaybackService.class)
                     .putExtra(PlaybackService.EXTRA_SEARCH_BUNDLE, intent.getExtras());
-            startService(serviceInent);
+            Util.startService(this, serviceInent);
         } else if (AudioPlayerContainerActivity.ACTION_SHOW_PLAYER.equals(action)) {
             startActivity(new Intent(this, tv ? AudioPlayerActivity.class : MainActivity.class));
         } else {
@@ -96,9 +93,9 @@ public class StartActivity extends Activity {
         finish();
     }
 
-    private void startMedialibrary(boolean firstRun, boolean upgrade) {
-        if (!VLCApplication.getMLInstance().isInitiated() && Permissions.canReadStorage())
-            startService(new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class)
+    private void startMedialibrary(final boolean firstRun, final boolean upgrade) {
+        if (!VLCApplication.getMLInstance().isInitiated() && Permissions.canReadStorage(StartActivity.this))
+            startService(new Intent(MediaParsingService.ACTION_INIT, null, StartActivity.this, MediaParsingService.class)
                     .putExtra(EXTRA_FIRST_RUN, firstRun)
                     .putExtra(EXTRA_UPGRADE, upgrade));
     }
